@@ -197,22 +197,22 @@ class IotToKinesisStreams(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="iotActionsRole")
     def iot_actions_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "iotActionsRole"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="iotTopicRule")
     def iot_topic_rule(self) -> aws_cdk.aws_iot.CfnTopicRule:
         return typing.cast(aws_cdk.aws_iot.CfnTopicRule, jsii.get(self, "iotTopicRule"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="kinesisStream")
     def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
         return typing.cast(aws_cdk.aws_kinesis.Stream, jsii.get(self, "kinesisStream"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
@@ -248,7 +248,7 @@ class IotToKinesisStreamsProps:
         :summary: The properties for the IotToKinesisFirehoseToS3 Construct
         '''
         if isinstance(iot_topic_rule_props, dict):
-            iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
+            iot_topic_rule_props = CfnTopicRuleProps(**iot_topic_rule_props)
         if __debug__:
             type_hints = typing.get_type_hints(IotToKinesisStreamsProps.__init__)
             check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
